from buildutils import download_and_check, configure, make, apply_patch
import utils
from package import Package
from Path import Path

class Beast(Package):
  def full_name (self):
    return "beast-20090519"

  def download (self):
    download_and_check ("http://space.twc.de/~stefan/download/beast-20090519.tar.bz2",
                        "c168b73a133286bf6811890ba0376233")

  def extract (self):
    self.clear_and_unpack ("beast-20090519.tar.bz2", "beast-20090519")

  def patch (self):
    apply_patch ("000_configure_ogg_vorbis.diff", "beast-20090519", 0)
    apply_patch ("001_configure_xmllint_check.diff", "beast-20090519", 0)
    apply_patch ("002_poll_constants.diff", "beast-20090519", 1)
    apply_patch ("003_bash_vs_sh_shell.diff", "beast-20090519", 1)
    apply_patch ("004_beast_birnet.diff", "beast-20090519", 1)
    apply_patch ("005_beast_sfi.diff", "beast-20090519", 1)
    apply_patch ("006_beast_birnet_tests.diff", "beast-20090519", 1)
    apply_patch ("007_g_print_and_bse.diff", "beast-20090519", 1)
    apply_patch ("008_misc_fixes.diff", "beast-20090519", 1)
    apply_patch ("009_inline_lib_make.diff", "beast-20090519", 1)
    apply_patch ("010_plugin_ext_crawler.diff", "beast-20090519", 1)
    apply_patch ("011_freeverb_sfi.diff", "beast-20090519", 1)
    apply_patch ("012_seq_waiter_and_domain.diff", "beast-20090519", 1)
    apply_patch ("013_doxer_portability.diff", "beast-20090519", 1)
    apply_patch ("014_scmoff_docoff_relocate.diff", "beast-20090519", 2)
    apply_patch ("015_engine_wakeup_and_portaudio.diff", "beast-20090519", 2)
    apply_patch ("016_relocate_via_exename.diff", "beast-20090519", 0)

  def compile (self):
    dbg = "--enable-debug" if self.config.ENABLE_DEBUG else "--disable-debug"
    configure ([ "sh", "autogen.sh", "--prefix", self.config.PREFIX.msys(),
                  "--enable-maintainer-mode", # po directory doesn't compile without it
                 dbg,
                  "LIBZ=-lz",
                  "LDFLAGS=-L" + self.config.PREFIX.join (Path ("lib")).msys(),
                  "CFLAGS='-I" + self.config.PREFIX.join (Path ("include")).msys() + "'" ],
                  "beast-20090519")
    make ([ "make" ], "beast-20090519")

  def dist_image (self):
    self.dist_image_with_make_install ("beast-20090519")

  def install (self):
    self.install_with_dist_image()

import packages.libs.libogg
import packages.libs.libvorbis
import packages.libs.libgnomecanvas
import packages.devel.libtool
import packages.devel.guile

deps = (packages.libs.libogg.packages()
     +  packages.libs.libvorbis.packages()
     +  packages.libs.libgnomecanvas.packages()
     +  packages.devel.libtool.packages()
     +  packages.devel.guile.packages())

def packages():
  return deps + [ Beast() ]
